@@ -1,10 +1,10 @@
 ;;; php-face.el --- Face definitions for PHP script  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2022  Friends of Emacs-PHP development
+;; Copyright (C) 2023  Friends of Emacs-PHP development
 
 ;; Author: USAMI Kenta <tadsan@zonu.me>
 ;; Created: 5 May 2019
-;; Version: 1.24.2
+;; Version: 1.25.0
 ;; Keywords: faces, php
 ;; Homepage: https://github.com/emacs-php/php-mode
 ;; License: GPL-3.0-or-later
@@ -145,7 +145,7 @@
   :group 'php-faces
   :tag "PHP Constant")
 
-(defface php-constant-assign '((t (:inherit font-lock-type-face)))
+(defface php-constant-assign '((t (:inherit php-constant)))
   "PHP Mode face used to highlight constant assigning (\"const\" statement)."
   :group 'php-faces
   :tag "PHP Constant Assign")
